# tests/hdplisp/قلب

## tests/hdplisp/قلب/قلب.apc.hdpl.lisp

The file [قلب.apc.hdpl.lisp](قلب.apc.hdpl.lisp) is an Hello world. This file may
be used on eventual very early tests of HDPLisp.


### Source
- <https://github.com/nasser/--->
- Some additional code is at
  - https://github.com/nasser/---/tree/master/public/lib

### Language variant `apc` on `apc.hdpl.lisp` (and not `ara.hdpl.lisp`)
> "The current version is in Lebanese
  Arabic by design, future versions will be in Standard and قول will be
  changed to قل. Are there any other typos?"
  -- nasser commented on 27 Jan 2013https://github.com/nasser/---/issues/8#issuecomment-12755608


> - "Lebanese Arabic" returns this [Lebanese Arabic
>   on Wikipedia](https://en.wikipedia.org/wiki/Lebanese_Arabic):
>   with ISO 639-3 apc
>   - apc on ISO 369-3 https://iso639-3.sil.org/code/apc

## More about `قلب`

From <https://www.mic.com/articles/130331/this-arabic-programming-language-shows-how-computers-revolve-around-the-western-world>

>> "Arabic people have a very intense relationship to text, and a lot of the culture is predicated on language itself," Nasser told Mic. "So I wanted to bring as much of the Arab tradition of calligraphy into the computer science tradition of text and source code."

>> (...)

>> "But Qlb can only be used in isolation. Like an atomic element created for a fraction of a second in a laboratory, programs written in Qlb can only exist in the environment where they're created. Once they start trying to interact with the rest of the web, everything falls apart. File names can't be read, the operating system rejects the syntax — Qlb was even part of a documentary on experimental design projects called Clouds that itself was created as a computer program that crashed once mention of Qlb was inserted."

>> (...)

>> ""If you're inventing computing in Bell Labs in New Jersey, you use the simplest thing possible, you squeeze the alphabet in and you get it done," Nasser said. **"But a side effect to that is that it's all in English — the standards we've adopted have encoded that alphabet**. So while Qlb is, formally speaking, complete, **it can never be usable in a meaningful way**."